@@ -1,14 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "importimapsettingspasswordtest.h"
 
-ImportImapSettingsPasswordTest::ImportImapSettingsPasswordTest()
-{
-}
+ImportImapSettingsPasswordTest::ImportImapSettingsPasswordTest() = default;
 
 void ImportImapSettingsPasswordTest::importPasswords(const SieveEditorUtil::SieveServerConfig &_config, const QString &filename, bool reuseImapSettings)
 {
