@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -20,9 +20,7 @@ ImportImapSettingsThunderbirdCheckJob::ImportImapSettingsThunderbirdCheckJob(QOb
 {
 }
 
-ImportImapSettingsThunderbirdCheckJob::~ImportImapSettingsThunderbirdCheckJob()
-{
-}
+ImportImapSettingsThunderbirdCheckJob::~ImportImapSettingsThunderbirdCheckJob() = default;
 
 // Copy from mailimporter
 QMap<QString, QString> ImportImapSettingsThunderbirdCheckJob::listProfile(QString &currentProfile, const QString &defaultSettingPath)
