@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -18,9 +18,7 @@ public:
 
 private:
     struct placeHolderTextInfo {
-        placeHolderTextInfo()
-        {
-        }
+        placeHolderTextInfo() = default;
 
         placeHolderTextInfo(const QString &t, const QString &info)
             : text(t)
