@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -661,7 +661,7 @@ QString SieveEditorMainWidget::currentHelpTitle() const
             return page->currentHelpTitle();
         }
     }
-    return QString();
+    return {};
 }
 
 QUrl SieveEditorMainWidget::currentHelpUrl() const
@@ -673,7 +673,7 @@ QUrl SieveEditorMainWidget::currentHelpUrl() const
             return page->currentHelpUrl();
         }
     }
-    return QUrl();
+    return {};
 }
 
 bool SieveEditorMainWidget::printSupportEnabled() const
